@@ -34,7 +34,8 @@
 #include <gtk/gtk.h>
 
 /* Xfce includes */
-#include <libxfcegui4/libxfcegui4.h>
+//#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 /* Package includes */
 #include <sensors-interface-common.h>
@@ -107,7 +108,7 @@ fill_gtkTreeStore (GtkTreeStore *model, t_chip *chip, t_tempscale scale, t_senso
 
 #ifdef HAVE_LIBNOTIFY7
                 nn = notify_notification_new (summary, body, icon);
-#elseif HAVE_LIBNOTIFY4
+#elif HAVE_LIBNOTIFY4
                 nn = notify_notification_new (summary, body, icon, NULL);
 #endif
                 notify_notification_show(nn, &error);
@@ -483,7 +484,7 @@ init_widgets (t_sensors_dialog *sd)
                             iter,
                             0, chipfeature->name,
                             1, "0.0",        /* chipfeature->formatted_value */
-                            2, False,        /* chipfeature->show */
+                            2, FALSE,        /* chipfeature->show */
                             3, "#000000",    /* chipfeature->color */
                             4, 0.0,            /* chipfeature->min_value */
                             5, 0.0,            /* chipfeature->max_value */
